// @flow

import React, { type Element } from 'react'
import { themr } from 'react-css-themr'
import splitItems from './splitItems'

function FeaturedListView({
  items,
  showFeatured = true,
  subFeaturedCount = 3,
  renderFeature,
  renderSubFeatureList,
  renderRemainList,
  theme,
}: {
  items: *[],
  showFeatured?: boolean,
  subFeaturedCount?: number,
  renderFeature: (item: *) => Element<*>,
  renderSubFeatureList: (item: *[]) => Element<*>,
  renderRemainList: (item: *[]) => Element<*>,
  theme: {
    root?: string,
    featuredWrapper?: string,
    featuredItemWrapper?: string,
    subFeaturedList?: string,
    subFeaturedItemWrapper?: string,
    remainList?: string,
    remainItemWrapper?: string,
  },
}) {
  const { featuredItem, subFeaturedItems, remainItems } = splitItems({
    items,
    showFeatured,
    subFeaturedCount,
  })

  return (
    <div className={theme.root}>
      <div data-element="Featured" className={theme.featuredWrapper}>
        <div className={theme.featuredItemWrapper}>
          {renderFeature(featuredItem)}
        </div>
        <div data-element="SubFeaturedList" className={theme.subFeaturedList}>
          {renderSubFeatureList(subFeaturedItems)}
        </div>
      </div>
      <div data-element="RemainList" className={theme.remainList}>
        {renderRemainList(remainItems)}
      </div>
    </div>
  )
}

FeaturedListView.defaultProps = {
  showFeatured: true,
  subFeaturedCount: 3,
}

export default themr('FeaturedList', {}, { composeTheme: 'softly' })(
  FeaturedListView,
)
