// @flow

import React, { PureComponent } from 'react'
import Lightbox from 'react-images'
import { themr } from 'react-css-themr'
import ImageItem from 'components/ImageItem'
import { type ImageProps } from 'components/Image'
import { imageFromId } from 'components/Image/cloudinary'

type GalleryItem = {
  image: ImageProps,
}

type Props = {
  items: GalleryItem[],
  fullTransform: string,
  thumbnailTransform: string,
  theme: *,
}

class ImageGallery extends PureComponent<Props, any> {
  static defaultProps = {
    fullTransform: 'w_1200',
    thumbnailTransform: 'w_400',
  }
  constructor(props: any) {
    super(props)
    const { items, fullTransform } = props || {}
    const gallery = (items || []).map(({ image }) => {
      if (!image) return null
      const src = imageFromId({
        ...image,
        transform: fullTransform,
      })
      return { src }
    })
    this.state = {
      gallery,
      opened: false,
      selected: 0,
    }
  }
  render() {
    const { items, thumbnailTransform, theme = {} } = this.props
    const { selected, opened, gallery } = this.state
    return (
      <div data-component="ImageGallery" className={theme.root}>
        {(items || []).map((item, idx) => (
          <div key={idx} className={theme.itemWrapper}>
            <ImageItem
              image={{
                image: {
                  ...item.image,
                  transform: thumbnailTransform,
                },
              }}
              {...item.image}
              asBackground
              theme={theme.item}
              onClick={() => this.setState({ selected: idx, opened: true })}
            />
          </div>
        ))}
        <Lightbox
          currentImage={selected}
          images={gallery}
          isOpen={opened}
          onClickPrev={() => {
            this.setState({
              selected: selected - 1 < 0 ? selected : selected - 1,
            })
          }}
          onClickNext={() => {
            this.setState({
              selected: selected + 1 >= items.length ? 0 : selected + 1,
            })
          }}
          onClose={() => this.setState({ opened: false })}
        />
      </div>
    )
  }
}

export default themr('ImageGallery', {}, { composeTheme: 'softly' })(ImageGallery)
