// @flow

import React from 'react'
import Section, { type SectionProps } from '../Section'

export type SectionsData = {
  type: string,
  data: *,
  section: SectionProps,
  theme: *,
}

export type SectionsProps = {
  sections: SectionsData[],
  components: { [key: string]: * },
}

function Sections({ sections, components }: SectionsProps) {
  return sections.map(({ type, data, section, theme }, idx) => {
    const Component = components[type]
    if (!section || Object.keys(section).length === 0) {
      return <Component key={idx} {...data} theme={theme} />
    }
    return (
      <Section key={idx} {...section} theme={theme.section || {}}>
        <Component {...data} theme={theme} />
      </Section>
    )
  })
}

export default Sections
